@@ -56,7 +56,7 @@ OPTIONS = {
     # "source_suffix": ".rst",
     # The master toctree document.
     "master_doc": "index",
-    "language": None,
+    "language": "en",
     # List of patterns, relative to source directory, that match files and
     # directories to ignore when looking for source files.
     "exclude_patterns": ["static", "templates"],
