@@ -479,7 +479,7 @@ def setup_edit_url(app, pagename, templatename, context, doctree):
             doc_path = f"{doc_path}/"
 
         default_provider_urls = {
-            "github_url": "https://github.com",
+            "github_url": "",
         }
 
         edit_url_attrs = {}
